Index: content/gpu/gpu_child_thread.h |
diff --git a/content/gpu/gpu_child_thread.h b/content/gpu/gpu_child_thread.h |
index 1ee30fa9003d87c73d5aa2de0b0d715fccd22525..3882fa526d254ce6886bdd9ae77b81ed21f32c7a 100644 |
--- a/content/gpu/gpu_child_thread.h |
+++ b/content/gpu/gpu_child_thread.h |
@@ -127,7 +127,8 @@ class GpuChildThread : public ChildThreadImpl, |
#endif |
void OnLoseAllContexts(); |
- void BindServiceFactoryRequest(shell::mojom::ServiceFactoryRequest request); |
+ void BindServiceFactoryRequest( |
+ service_manager::mojom::ServiceFactoryRequest request); |
// Set this flag to true if a fatal error occurred before we receive the |
// OnInitialize message, in which case we just declare ourselves DOA. |
@@ -159,11 +160,12 @@ class GpuChildThread : public ChildThreadImpl, |
// The gpu::GpuMemoryBufferFactory instance used to allocate GpuMemoryBuffers. |
gpu::GpuMemoryBufferFactory* const gpu_memory_buffer_factory_; |
// ServiceFactory for shell::Service hosting. |
std::unique_ptr<GpuServiceFactory> service_factory_; |
- // Bindings to the shell::mojom::ServiceFactory impl. |
- mojo::BindingSet<shell::mojom::ServiceFactory> service_factory_bindings_; |
+ // Bindings to the service_manager::mojom::ServiceFactory impl. |
+ mojo::BindingSet<service_manager::mojom::ServiceFactory> |
+ service_factory_bindings_; |
DISALLOW_COPY_AND_ASSIGN(GpuChildThread); |
}; |
@@ -159,11 +160,12 @@ class GpuChildThread : public ChildThreadImpl, |
// The gpu::GpuMemoryBufferFactory instance used to allocate GpuMemoryBuffers. |
gpu::GpuMemoryBufferFactory* const gpu_memory_buffer_factory_; |
- // ServiceFactory for shell::Service hosting. |
+ // ServiceFactory for service_manager::Service hosting. |
std::unique_ptr<GpuServiceFactory> service_factory_; |